==> haskell-crypton-x509-1.7.6-42-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypton-x509.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 crypton-x509
version:              1.7.6
visibility:           public
id:                   crypton-x509-1.7.6-BxdovUSlNoP1M4XPzqsjUN
key:                  crypton-x509-1.7.6-BxdovUSlNoP1M4XPzqsjUN
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-certificate
synopsis:             X509 reader and writer
description:          X509 reader and writer. please see README
category:             Data
abi:                  91b067d68692781808831401ca4ec7c9
exposed:              True
exposed-modules:      Data.X509 Data.X509.EC
hidden-modules:
    Data.X509.Internal Data.X509.CertificateChain
    Data.X509.AlgorithmIdentifier Data.X509.DistinguishedName
    Data.X509.Cert Data.X509.PublicKey Data.X509.PrivateKey
    Data.X509.Ext Data.X509.ExtensionRaw Data.X509.CRL Data.X509.OID
    Data.X509.Signed

import-dirs:          /usr/lib/ghc-9.2.8/site-local/crypton-x509-1.7.6
library-dirs:         /usr/lib/ghc-9.2.8/site-local/crypton-x509-1.7.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-x509
hs-libraries:         HScrypton-x509-1.7.6-BxdovUSlNoP1M4XPzqsjUN
depends:
    asn1-encoding-0.9.6-CpNkgZOuAkNJ5r4cSayp0v
    asn1-parse-0.9.5-Ey5h8t0DjYc72odn2hjlxk
    asn1-types-0.3.4-5n8ikSO2ZhQ2VMKV4009uD base-4.16.4.0
    bytestring-0.11.4.0 containers-0.6.5.1
    crypton-0.34-FRrPFcoOGm4LHlOagkFb1b
    hourglass-0.2.12-Kg8lgtde2NwjlIYM9VvWk
    memory-0.18.0-Hvum6HaH78UJG59LYyNLK1
    pem-0.2.4-FAcuywtMEBuL2NeN5yHYPa transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-crypton-x509/html/crypton-x509.haddock

haddock-html:         /usr/share/doc/haskell-crypton-x509/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypton-x509-1.7.6-43-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypton-x509.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 crypton-x509
version:              1.7.6
visibility:           public
id:                   crypton-x509-1.7.6-8Keupgv6KJGDfa1SnJh6QN
key:                  crypton-x509-1.7.6-8Keupgv6KJGDfa1SnJh6QN
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-certificate
synopsis:             X509 reader and writer
description:          X509 reader and writer. please see README
category:             Data
abi:                  0d1fc7e1a9d38a8e489c12b19b10199c
exposed:              True
exposed-modules:      Data.X509 Data.X509.EC
hidden-modules:
    Data.X509.Internal Data.X509.CertificateChain
    Data.X509.AlgorithmIdentifier Data.X509.DistinguishedName
    Data.X509.Cert Data.X509.PublicKey Data.X509.PrivateKey
    Data.X509.Ext Data.X509.ExtensionRaw Data.X509.CRL Data.X509.OID
    Data.X509.Signed

import-dirs:          /usr/lib/ghc-9.2.8/site-local/crypton-x509-1.7.6
library-dirs:         /usr/lib/ghc-9.2.8/site-local/crypton-x509-1.7.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-x509
hs-libraries:         HScrypton-x509-1.7.6-8Keupgv6KJGDfa1SnJh6QN
depends:
    asn1-encoding-0.9.6-12vyWbdZjh184O3ewFlB7g
    asn1-parse-0.9.5-TnxDC3hka4KCqqzapoatN
    asn1-types-0.3.4-7a8dHgKSLzP842ZmbplaUK base-4.16.4.0
    bytestring-0.11.4.0 containers-0.6.5.1
    crypton-0.34-DYcYdZeSswj6ANhBOnm6tG
    hourglass-0.2.12-5VgAUtHEa0i6r7OiCZkAkK
    memory-0.18.0-Hvum6HaH78UJG59LYyNLK1
    pem-0.2.4-JLaK1jx0FMi9AmNIwZtlpI transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-crypton-x509/html/crypton-x509.haddock

haddock-html:         /usr/share/doc/haskell-crypton-x509/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
